@@ -35,16 +35,13 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import hashlib
-
 import passlib.crypto.des
+from samba.crypto import md4_hash_blob
 
 
 def md4(data):
     # type: (bytes) -> bytes
-    md = hashlib.new('md4')
-    md.update(data)
-    return md.digest()
+    return md4_hash_blob(data)
 
 
 def DesEncrypt(data, key):
